@@ -403,7 +403,7 @@ const Z_int DateCalc_Days_in_Month_[2][13] =
     { 0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
 };
 
-#define DateCalc_LANGUAGES 11
+#define DateCalc_LANGUAGES 13
 
 Z_int  DateCalc_Language = 1; /* Default = 1 (English) */
 
@@ -457,6 +457,14 @@ const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32] =
         "???", "tammikuu", "helmikuu", "maaliskuu", "huhtikuu",
         "toukokuu", "keskuu", "heinkuu", "elokuu",
         "syyskuu", "lokakuu", "marraskuu", "joulukuu"
+    },
+    {
+        "???", "Janur", "Februr", "Mrcius", "prilis", "Mjus", "Jnius",
+        "Jlius", "Augusztus", "Szeptember", "Oktber", "November", "December"
+    },
+    {
+        "???", "Stycze", "Luty", "Marzec", "Kwiecie", "Maj", "Czerwiec",
+        "Lipiec", "Sierpie", "Wrzesie", "Padziernik", "Listopad", "Grudzie"
     }
 };
 
@@ -509,6 +517,14 @@ const N_char DateCalc_Day_of_Week_to_Text_[DateCalc_LANGUAGES+1][8][32] =
     {
         "???", "maanantai", "tiistai", "keskiviikko",
         "torstai", "perjantai", "lauantai", "sunnuntai"
+    },
+    {
+        "???", "htf", "kedd", "szerda",
+        "cstrtk", "pntek", "szombat", "vasrnap"
+    },
+    {
+        "???", "Poniedziaek", "Wtorek", "roda",
+        "Czwartek", "Pitek", "Sobota", "Niedziela"
     }
 };
 
@@ -552,6 +568,12 @@ const N_char DateCalc_Day_of_Week_Abbreviation_[DateCalc_LANGUAGES+1][8][4] =
     },
     {
         "", "", "", "", "", "", "", ""    /* 11 */
+    },
+    {
+        "", "", "", "", "", "", "", ""    /* 12 */
+    },
+    {
+        "???", "Pn", "Wt", "r", "Cz", "Pt", "So", "Ni"    /* 13 */
     }
 };
 
@@ -576,14 +598,16 @@ const N_char DateCalc_Date_Long_Format_[DateCalc_LANGUAGES+1][64] =
     "%s, %d. %s %d",                    /*  8  Norsk       */
     "%s, %d %s %d",                     /*  9  Svenska     */
     "%s, %d. %s %d",                    /* 10  Dansk       */
-    "%s, %d. %sta %d"                   /* 11  suomi       */
+    "%s, %d. %sta %d",                  /* 11  suomi       */
+    "%d. %s %d., %s",                   /* 12  Magyar      */
+    "%s, %d %s %d"                      /* 13  Polski      */
 };
 
 const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32] =
 {
     "???", "English", "Franais", "Deutsch", "Espaol",
     "Portugus", "Nederlands", "Italiano", "Norsk", "Svenska",
-    "Dansk", "suomi"
+    "Dansk", "suomi", "Magyar", "Polski"
 };
 
 /*****************************************************************************/
@@ -1243,6 +1267,14 @@ boolean DateCalc_localtime(Z_int  *year, Z_int *month, Z_int *day,
     return(false);
 }
 
+/* MacOS (Classic):                                            */
+/* <695056.0>     = Fri  1-Jan-1904 00:00:00 (time=0x00000000) */
+/* <744766.23295> = Mon  6-Feb-2040 06:28:15 (time=0xFFFFFFFF) */
+
+/* Unix:                                                       */
+/* <719163.0>     = Thu  1-Jan-1970 00:00:00 (time=0x00000000) */
+/* <744018.11647> = Tue 19-Jan-2038 03:14:07 (time=0x7FFFFFFF) */
+
 boolean DateCalc_mktime(time_t *seconds,
                         Z_int year, Z_int month, Z_int day,
                         Z_int hour, Z_int min,   Z_int sec,
@@ -1250,11 +1282,41 @@ boolean DateCalc_mktime(time_t *seconds,
 {
     struct tm date;
 
+    *seconds = (time_t) 0;
+
+#ifdef MACOS_TRADITIONAL
+    if ( (year  < 1904) or (year  > 2040) or
+#else
+    if ( (year  < 1970) or (year  > 2038) or
+#endif
+         (month <    1) or (month >   12) or
+         (day   <    1) or (day   >   31) or
+         (hour  <    0) or (hour  >   23) or
+         (min   <    0) or (min   >   59) or
+         (sec   <    0) or (sec   >   59) )
+    return(false);
+
+#ifdef MACOS_TRADITIONAL
+    if ( (year == 2040) and ( (month >  2) or
+                            ( (month == 2) and ( (day >  6) or
+                                               ( (day == 6) and ( (hour >  6) or
+                                                                ( (hour == 6) and ( (min >  28) or
+                                                                                  ( (min == 28) and (sec > 15) ) ))))))) )
+    return(false);
+#else
+    if ( (year == 2038) and ( (month >  1) or
+                            ( (month == 1) and ( (day >  19) or
+                                               ( (day == 19) and ( (hour >  3) or
+                                                                 ( (hour == 3) and ( (min >  14) or
+                                                                                   ( (min == 14) and (sec > 7) ) ))))))) )
+    return(false);
+#endif
+
     year -= 1900;
     month--;
-    if (doy >  1) doy--;    else
-    if (doy <  0) doy = -1;
-    if (dow <  0) dow = -1; else
+    if (doy <= 0) doy = -1;
+    else          doy--;
+    if (dow <= 0) dow = -1; else
     if (dow == 7) dow =  0;
     if (dst != 0)
     {
@@ -1324,27 +1386,51 @@ boolean DateCalc_timezone(Z_int *year, Z_int *month, Z_int *day,
     return(false);
 }
 
-/* Substitute for BSD's timegm(3) function: */
+/* MacOS (Classic):                                            */
+/* <695056.0>     = Fri  1-Jan-1904 00:00:00 (time=0x00000000) */
+/* <744766.23295> = Mon  6-Feb-2040 06:28:15 (time=0xFFFFFFFF) */
 
+/* Unix:                                                       */
 /* <719163.0>     = Thu  1-Jan-1970 00:00:00 (time=0x00000000) */
 /* <744018.11647> = Tue 19-Jan-2038 03:14:07 (time=0x7FFFFFFF) */
 
+#ifdef MACOS_TRADITIONAL
+    #define DateCalc_DAYS_TO_EPOCH  695056L
+    #define DateCalc_DAYS_TO_OVFLW  744766L
+    #define DateCalc_SECS_TO_OVFLW   23295L
+#else
+    #define DateCalc_DAYS_TO_EPOCH  719163L
+    #define DateCalc_DAYS_TO_OVFLW  744018L
+    #define DateCalc_SECS_TO_OVFLW   11647L
+#endif
+
+/* Substitute for BSD's timegm(3) function: */
+
 boolean DateCalc_date2time(time_t *seconds,
                            Z_int year, Z_int month, Z_int day,
                            Z_int hour, Z_int min,   Z_int sec)
 {
     Z_long days;
+#ifdef MACOS_TRADITIONAL
+    N_long secs;
+#else
     Z_long secs;
+#endif
+
+    *seconds = (time_t) 0;
 
     days = DateCalc_Date_to_Days(year,month,day);
     secs = (((hour * 60L) + min) * 60L) + sec;
-    if ((days < 719163L) or (secs < 0L) or
-        (days > 744018L) or ((days == 744018L) and (secs > 11647L)))
-    {
-        *seconds = (time_t) -1;
-        return(false);
-    }
-    *seconds = (time_t) (((days - 719163L) * 86400L) + secs);
+
+    if (   (days <  DateCalc_DAYS_TO_EPOCH) or
+#ifndef MACOS_TRADITIONAL
+           (secs <  0L) or
+#endif
+           (days >  DateCalc_DAYS_TO_OVFLW) or
+         ( (days == DateCalc_DAYS_TO_OVFLW) and (secs > DateCalc_SECS_TO_OVFLW) ) )
+    return(false);
+
+    *seconds = (time_t) (((days - DateCalc_DAYS_TO_EPOCH) * 86400L) + secs);
     return(true);
 }
 
@@ -1354,6 +1440,18 @@ boolean DateCalc_time2date(Z_int *year, Z_int *month, Z_int *day,
                            Z_int *hour, Z_int *min,   Z_int *sec,
                            time_t seconds)
 {
+#ifdef MACOS_TRADITIONAL
+    N_long ss = (N_long) seconds;
+    N_long mm;
+    N_long hh;
+    N_long dd;
+
+    dd = (N_long) (ss / 86400L);
+    ss -= dd * 86400L;
+    mm = (N_long) (ss / 60L);
+    ss -= mm * 60L;
+    hh = (N_long) (mm / 60L);
+#else
     Z_long ss = (Z_long) seconds;
     Z_long mm;
     Z_long hh;
@@ -1365,8 +1463,10 @@ boolean DateCalc_time2date(Z_int *year, Z_int *month, Z_int *day,
     mm = (Z_long) (ss / 60L);
     ss -= mm * 60L;
     hh = (Z_long) (mm / 60L);
+#endif
+
     mm -= hh * 60L;
-    dd += 719162L;
+    dd += (DateCalc_DAYS_TO_EPOCH-1L);
     *sec   = (Z_int) ss;
     *min   = (Z_int) mm;
     *hour  = (Z_int) hh;
@@ -1960,7 +2060,7 @@ charptr DateCalc_English_Ordinal(charptr result, Z_int number)
     N_int digit;
 
     sprintf((char *)result, "%d", number);
-    if (length = strlen((char *)result))
+    if ((length = strlen((char *)result)))
     {
         if ( not
              (
@@ -1998,6 +2098,16 @@ charptr DateCalc_Date_to_Text_Long(Z_int year, Z_int month, Z_int day)
                     DateCalc_English_Ordinal(buffer,day),
                     year );
                 break;
+            case 12:
+                sprintf(
+                    (char *)string,
+                    (char *)DateCalc_Date_Long_Format_[DateCalc_Language],
+                    year,
+                    DateCalc_Month_to_Text_[DateCalc_Language][month],
+                    day,
+                    DateCalc_Day_of_Week_to_Text_[DateCalc_Language]
+                        [DateCalc_Day_of_Week(year,month,day)] );
+                break;
             default:
                 sprintf(
                     (char *)string,
@@ -2104,15 +2214,16 @@ void DateCalc_Dispose(charptr string)
 
 charptr DateCalc_Version(void)
 {
-    return( (charptr) "5.0" );
+    return( (charptr) "5.1" );
 }
 
 /*****************************************************************************/
-/*  VERSION:  5.0                                                            */
+/*  VERSION:  5.1                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.1   08.09.02  Added conditional changes for MacOS/MacPerl.   */
 /*    Version 5.0   10.10.01  New YMD/HMS functions, replaced <ctype.h>, ... */
 /*    Version 4.3   08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)        */
 /*    Version 4.2   07.09.98  No changes.                                    */
@@ -2148,7 +2259,7 @@ charptr DateCalc_Version(void)
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1993 - 2001 by Steffen Beyer.                            */
+/*    Copyright (c) 1993 - 2002 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
