@@ -407,7 +407,7 @@ extern const Z_int DateCalc_Days_in_Month_[2][13];
 };
 */
 
-#define DateCalc_LANGUAGES 11
+#define DateCalc_LANGUAGES 13
 
 extern Z_int  DateCalc_Language; /* Default = 1 (English) */
 
@@ -462,6 +462,14 @@ extern const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32];
         "???", "tammikuu", "helmikuu", "maaliskuu", "huhtikuu",
         "toukokuu", "keskuu", "heinkuu", "elokuu",
         "syyskuu", "lokakuu", "marraskuu", "joulukuu"
+    },
+    {
+        "???", "Janur", "Februr", "Mrcius", "prilis", "Mjus", "Jnius",
+        "Jlius", "Augusztus", "Szeptember", "Oktber", "November", "December"
+    },
+    {
+        "???", "Stycze", "Luty", "Marzec", "Kwiecie", "Maj", "Czerwiec",
+        "Lipiec", "Sierpie", "Wrzesie", "Padziernik", "Listopad", "Grudzie"
     }
 };
 */
@@ -516,6 +524,14 @@ extern const N_char DateCalc_Day_of_Week_to_Text_[DateCalc_LANGUAGES+1][8][32];
     {
         "???", "maanantai", "tiistai", "keskiviikko",
         "torstai", "perjantai", "lauantai", "sunnuntai"
+    },
+    {
+        "???", "htf", "kedd", "szerda",
+        "cstrtk", "pntek", "szombat", "vasrnap"
+    },
+    {
+        "???", "Poniedziaek", "Wtorek", "roda",
+        "Czwartek", "Pitek", "Sobota", "Niedziela"
     }
 };
 */
@@ -561,6 +577,12 @@ extern const N_char DateCalc_Day_of_Week_Abbreviation_[DateCalc_LANGUAGES+1][8][
     },
     {
         "", "", "", "", "", "", "", ""
+    },
+    {
+        "", "", "", "", "", "", "", ""
+    },
+    {
+        "???", "Pn", "Wt", "r", "Cz", "Pt", "So", "Ni"
     }
 };
 */
@@ -589,7 +611,9 @@ extern const N_char DateCalc_Date_Long_Format_[DateCalc_LANGUAGES+1][64];
     "%s, %d. %s %d",
     "%s, %d %s %d",
     "%s, %d. %s %d",
-    "%s, %d. %sta %d"
+    "%s, %d. %sta %d",
+    "%d. %s %d., %s",
+    "%s, %d %s %d"
 };
 */
 
@@ -598,7 +622,7 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 {
     "???", "English", "Franais", "Deutsch", "Espaol",
     "Portugus", "Nederlands", "Italiano", "Norsk", "Svenska",
-    "Dansk", "suomi"
+    "Dansk", "suomi", "Magyar", "Polski"
 };
 */
 
@@ -607,11 +631,12 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*  VERSION:  5.0                                                            */
+/*  VERSION:  5.1                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.1   08.09.02  Added conditional changes for MacOS/MacPerl.   */
 /*    Version 5.0   10.10.01  New YMD/HMS functions, replaced <ctype.h>, ... */
 /*    Version 4.3   08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)        */
 /*    Version 4.2   07.09.98  No changes.                                    */
@@ -647,7 +672,7 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1993 - 2001 by Steffen Beyer.                            */
+/*    Copyright (c) 1993 - 2002 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
